#	File: cdfplottwo.r
#	Programmer: Tony Olsen
#	Date: October 17, 2005
# Input:
#	cdfest1 - dataframe with
#			x-value for cdf plot
#			y-value (cdf estimate)
#			lower confidence bound
#			upper confidence bound
#	cdfest2 - dataframe with
#			x-value for cdf plot
#			y-value (cdf estimate)
#			lower confidence bound
#			upper confidence bound
#	prop - plot as percent (TRUE default) or units
#	cex.legend - character expansion factor relative to current cex
#			for legend
#	legx - x-coordinate for legend, default is min(cdfest[,1])
#	legx - y-coordinate for legend, default is max(cdfest[,2])
#
# Output:
#	plot of cdf with confidence bounds	
cdfplottwo <- function(cdfest1,cdfest2,prop=TRUE,cex.legend=0.7,
   xlab=xlab, ylab=ylab, main=main, logx="",
	legx=max(cdfest1[,1],cdfest2[,1]),legy=min(cdfest1[,2],cdfest2[,2]),...){

if(prop == TRUE) {
	plot(cdfest1[,1],cdfest1[,2]  , log=logx,
		type='l',ylim=c(0,100), xlab=xlab, ylab=ylab, main=main)
	tvalue1 <- cdfest1[,2]>=5 & cdfest1[,2]<=95
	tvalue2 <- cdfest2[,2]>=5 & cdfest2[,2]<=95
}
else {
	plot(cdfest1[,1],cdfest1[,2],type='l',logx="", 
       xlab=xlab, ylab=ylab, main=main)
	tvalue1 <- cdfest1[,2]>=0.05*max(cdfest1[,2]) & 
			cdfest1[,2]<=0.95*max(cdfest1[,2])
	tvalue2 <- cdfest2[,2]>=0.05*max(cdfest2[,2]) & 
			cdfest2[,2]<=0.95*max(cdfest2[,2])
}
value <- cdfest1[,1][tvalue1]
upper <- cdfest1[,4][tvalue1]
lower <- cdfest1[,3][tvalue1]
lines(value,lower,lty=2,...)
lines(value,upper,lty=2,...)

# plot second cdf
lines(cdfest2[,1],cdfest2[,2], col='red')
value <- cdfest2[,1][tvalue2]
upper <- cdfest2[,4][tvalue2]
lower <- cdfest2[,3][tvalue2]
lines(value,lower,lty=2, col='red',...)
lines(value,upper,lty=2, col='red',...)

legend(x=legx,y=legy,
	legend=c('1st CDF estimate', '1st 95% Confidence Limits',
	         '2nd CDF estimate','2nd 95% Confidence Limits'),
	lty=c(1,2,1,2), col=c('black', 'black', 'red', 'red'), 
	bty='n', cex=cex.legend,
	xjust=1,yjust=0)
}







