# File: EXTENT_ESTIMATION.R
# Purpose: Extent estimation for Region 10 and states
#          Data files include final design information and
#          only have one record for each site from the probability sample
# Programmer: Tony Olsen
# Date: October 11, 2005
# Modified: Dan McKenzie
# Date: 1/26/06
# Data required: status_wgt_all7.csv

# Libraries required: psurvey.analysis 2.9
# read in data
StatWgt <- read.csv('Original Data/status_wgt_all7.csv')
names(StatWgt)
nrow(StatWgt)

########
# Population estimates for Target/NonTarget and Status categories
# How many stream km in each?
# Construct Target/NonTarget indicator
StatWgt$TNT <- StatWgt$STATUS_1
# recode levels to T=Target and NT=NonTarget
levels(StatWgt$TNT) <- list(T=c('LD', 'PB', 'TB', 'TS', 'TNS'), NT='NT')

## Need equal area coordinates for variance estimation
#  (uses x-site coords when available, design coords otherwise)
tmp <- marinus(StatWgt$POPLAT_DD, StatWgt$POPLONG_DD)
StatWgt$xmarinus <- tmp[,'x']
StatWgt$ymarinus <- tmp[,'y']

# Set up data for estimation
# which sites to use?
# create separate site files for extent, condition, or invasive plant estimates

sites.ext <- data.frame(SiteID=StatWgt$SITE_ID,
                Use=(StatWgt$EVALUATE=='Y' & !is.na(StatWgt$WGT_EXTENT)))
sites.con <- data.frame(SiteID=StatWgt$SITE_ID,
                Use=(StatWgt$USED=='Y'& !is.na(StatWgt$WGT_COND)))


# want estimates for what subpopulations?
# Create subpop variables
subpop <- data.frame(SiteID=StatWgt$SITE_ID, 
                     Region10=rep('Region 10', nrow(StatWgt)),
                     States=StatWgt$STATE)

# Provide design information-- 
#      change wgt variable for extent, condition, inv. plants
dsgn.ext <- data.frame(siteID=StatWgt$SITE_ID, 
                      stratum=StatWgt$STRATUM,
			                wgt=StatWgt$WGT_EXTENT, 
			                xcoord=StatWgt$xmarinus,
			                ycoord=StatWgt$ymarinus)
			
dsgn.con <- data.frame(siteID=StatWgt$SITE_ID, 
                       stratum=StatWgt$STRATUM,
			                 wgt=StatWgt$WGT_COND, 
			                 xcoord=StatWgt$xmarinus,
			                 ycoord=StatWgt$ymarinus)
				
				
# Provide categorical indicator data
data.cat <- data.frame(siteID=StatWgt$SITE_ID, 
                      TNT=StatWgt$TNT, 
				SiteStatus=StatWgt$STATUS_1)
					
# Do status population estimation for extent
popstatus.ext <- cat.analysis(sites = sites.ext, 
					subpop = subpop, 
					design = dsgn.ext,
  				data.cat = data.cat, 
					vartype = "Local", 
					conf = 95)
# Do same estimate but use other variance estimator
popstatusSRS.ext <- cat.analysis(sites = sites.ext, 
					subpop = subpop, 
					design = dsgn.ext,
 				data.cat = data.cat, 
					vartype = "SRS", 
					conf = 95)
# Note that the Local variance estimated std error and confidence bounds are smaller.

# write results out
write.table(popstatus.ext,'Eval_Extent_Est.csv',sep = ",",col.names=NA)
write.table(popstatusSRS.ext,'Eval_Extent_EstSRS.csv',sep = ",",col.names=NA)

# Do status population estimation for condition
popstatus.con <- cat.analysis(sites = sites.con, 
					subpop = subpop, 
					design = dsgn.con,
  				data.cat = data.cat, 
					vartype = "Local", 
					conf = 95)

# write results out
write.table(popstatus.con,'Used_Extent_Est.csv',sep = ",",col.names=NA)
